@@ -13,8 +13,12 @@ def enter_and_leave_log(func):
                 log.info(f"Entering {func.__name__},kwargs is {kwargs}")
             else:
                 log.info(f"Entering {func.__name__}")
-        result = func(*args, **kwargs)
-        log_str=f"Leaving {func.__name__},result type is {type(result)}, and result is {result}"
-        log.info(log_str[:100]+"...more to view log file")
-        return result
+        try:
+            result = func(*args, **kwargs)
+            log_str=f"Leaving {func.__name__},result type is {type(result)}, and result is {result}"
+            log.info(log_str)
+            return result
+        except Exception as e:
+            log.error(f"{func.__name__} error: {e}")
+            raise e
     return wrapper
\ No newline at end of file
